@@ -654,15 +654,20 @@ local function create_paths(luaversion_full)
       testing_paths.lua_interpreter = test_env.LUA_INTERPRETER or "lua"
    end
 
-   local bindirs = {
-      testing_paths.luadir .. "/bin",
-      testing_paths.luadir,
-   }
-   for _, bindir in ipairs(bindirs) do
-      local lua = bindir .. "/" .. testing_paths.lua_interpreter
-      if test_env.exists(lua) then
-         testing_paths.lua_bindir = bindir
-         testing_paths.lua = lua
+   local locations
+   if testing_paths.lua_interpreter:match("[/\\]") then
+      locations = { testing_paths.lua_interpreter }
+   else
+      locations = {
+         testing_paths.luadir .. "/bin/" .. testing_paths.lua_interpreter,
+         testing_paths.luadir .. "/" .. testing_paths.lua_interpreter,
+      }
+   end
+
+   for _, location in ipairs(locations) do
+      if test_env.exists(location) then
+         testing_paths.lua_bindir = location:match("(.*)[/\\][^/\\]*$")
+         testing_paths.lua = location
          break
       end
    end
@@ -915,7 +920,7 @@ local function mock_api_call(path)
    if test_env.TEST_TARGET_OS == "windows" then
       return test_env.execute(Q(test_env.testing_paths.win_tools .. "/wget") .. " --quiet --timeout=5 --tries=1 localhost:8080" .. path)
    else
-      return test_env.execute("curl localhost:8080" .. path)
+      return test_env.execute("curl -s localhost:8080" .. path)
    end
 end
 
@@ -1014,14 +1019,19 @@ function test_env.main()
    local rocks = {} -- names of rocks, required for building environment
    local urls = {}  -- names of rock and rockspec files to be downloaded
 
+   local env_vars = {
+      LUAROCKS_CONFIG = test_env.testing_paths.testrun_dir .. "/testing_config.lua"
+   }
+
    if test_env.TYPE_TEST_ENV == "full" then
       table.insert(urls, "/luafilesystem-${LUAFILESYSTEM}.src.rock")
       table.insert(urls, "/luasocket-${LUASOCKET}.src.rock")
       table.insert(urls, "/luasocket-${LUASOCKET}.rockspec")
+      table.insert(urls, "/luasec-${LUASEC}.src.rock")
       table.insert(urls, "/md5-1.2-1.src.rock")
       table.insert(urls, "/manifests/hisham/lua-zlib-1.2-0.src.rock")
       table.insert(urls, "/manifests/hisham/lua-bz2-0.2.1.1-1.src.rock")
-      rocks = {"luafilesystem", "luasocket", "md5", "lua-zlib", "lua-bz2"}
+      rocks = {"luafilesystem", "luasocket", "luasec", "md5", "lua-zlib", "lua-bz2"}
       if test_env.TEST_TARGET_OS ~= "windows" then
          if test_env.lua_version == "5.1" then
             table.insert(urls, "/bit32-${BIT32}.src.rock")
@@ -1030,6 +1040,8 @@ function test_env.main()
          table.insert(urls, "/luaposix-${LUAPOSIX}.src.rock")
          table.insert(rocks, "luaposix")
       end
+      assert(test_env.run.luarocks_nocov("config variables.OPENSSL_INCDIR " .. Q(test_env.OPENSSL_INCDIR), env_vars))
+      assert(test_env.run.luarocks_nocov("config variables.OPENSSL_LIBDIR " .. Q(test_env.OPENSSL_LIBDIR), env_vars))
    end
 
    -- luacov is needed for both minimal or full environment
@@ -1044,10 +1056,6 @@ function test_env.main()
    lfs.mkdir(testing_paths.testing_server)
    download_rocks(urls, testing_paths.testing_server)
 
-   local env_vars = {
-      LUAROCKS_CONFIG = test_env.testing_paths.testrun_dir .. "/testing_config.lua"
-   }
-
    build_environment(rocks, env_vars)
 
    prepare_mock_server_binary_rocks()
